"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const S3 = require("aws-sdk/clients/s3");
const lambda_framework_1 = require("lambda-framework");
const NodeCache = require("node-cache");
/**
 * Loads the template from AWS S3 bucket.
 */
class S3TemplateLoader {
    constructor(bucket, ttl) {
        this._s3 = new S3();
        this._bucket = bucket;
        if (ttl) {
            this._cache = new NodeCache({ stdTTL: ttl });
        }
    }
    load(fileName, callback) {
        this.getFromCache(fileName, (cacheErr, cacheValue) => {
            if (cacheErr) {
                callback(cacheErr, null);
            }
            else {
                if (cacheValue === undefined) {
                    this._s3.getObject({
                        Bucket: this._bucket,
                        Key: fileName
                    }, (err, data) => {
                        if (err) {
                            callback(err, null);
                        }
                        else {
                            const content = data.Body.toString();
                            const template = new lambda_framework_1.Template(fileName, content);
                            this.setToCache(template);
                            callback(null, template);
                        }
                    });
                }
                else {
                    callback(null, cacheValue);
                }
            }
        });
    }
    getFromCache(fileName, callback) {
        if (this._cache) {
            this._cache.get(fileName, callback);
        }
        else {
            callback(null, undefined);
        }
    }
    setToCache(template) {
        if (this._cache) {
            this._cache.set(template.fileName, template, (err, success) => {
                if (err || !success) {
                    console.error("Error saving template into cache: " + template.fileName, err);
                }
            });
        }
    }
}
exports.default = S3TemplateLoader;
//# sourceMappingURL=S3TemplateLoader.js.map